@@ -1,6 +1,8 @@
 """Apps for managing kernel specs."""
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
+from __future__ import annotations
+
 import errno
 import json
 import os.path
@@ -10,7 +12,6 @@ import typing as t
 from jupyter_core.application import JupyterApp, base_aliases, base_flags
 from traitlets import Bool, Dict, Instance, List, Unicode
 from traitlets.config.application import Application
-from traitlets.config.loader import Config
 
 from . import __version__
 from .kernelspec import KernelSpecManager
@@ -37,21 +38,21 @@ class ListKernelSpecs(JupyterApp):
         "debug": base_flags["debug"],
     }
 
-    def _kernel_spec_manager_default(self):
+    def _kernel_spec_manager_default(self) -> KernelSpecManager:
         return KernelSpecManager(parent=self, data_dir=self.data_dir)
 
-    def start(self):
+    def start(self) -> dict[str, t.Any] | None:  # type:ignore[override]
         """Start the application."""
         paths = self.kernel_spec_manager.find_kernel_specs()
         specs = self.kernel_spec_manager.get_all_specs()
         if not self.json_output:
             if not specs:
-                self.log.info("No kernels available")
-                return
+                print("No kernels available")
+                return None
             # pad to width of longest kernel name
             name_len = len(sorted(paths, key=lambda name: len(name))[-1])
 
-            def path_key(item):
+            def path_key(item: t.Any) -> t.Any:
                 """sort key function for Jupyter path priority"""
                 path = item[1]
                 for idx, prefix in enumerate(self.jupyter_path):
@@ -60,11 +61,11 @@ class ListKernelSpecs(JupyterApp):
                 # not in jupyter path, artificially added to the front
                 return (-1, path)
 
-            self.log.info("Available kernels:")
+            print("Available kernels:")
             for kernelname, path in sorted(paths.items(), key=path_key):
-                self.log.info("  %s    %s", kernelname.ljust(name_len), path)
+                print(f"  {kernelname.ljust(name_len)}    {path}")
         else:
-            print(json.dumps({"kernelspecs": specs}, indent=2))  # noqa
+            print(json.dumps({"kernelspecs": specs}, indent=2))
         return specs
 
 
@@ -85,13 +86,13 @@ class InstallKernelSpec(JupyterApp):
     usage = "jupyter kernelspec install SOURCE_DIR [--options]"
     kernel_spec_manager = Instance(KernelSpecManager)
 
-    def _kernel_spec_manager_default(self):
+    def _kernel_spec_manager_default(self) -> KernelSpecManager:
         return KernelSpecManager(data_dir=self.data_dir)
 
     sourcedir = Unicode()
     kernel_name = Unicode("", config=True, help="Install the kernel spec with this name")
 
-    def _kernel_name_default(self):
+    def _kernel_name_default(self) -> str:
         return os.path.basename(self.sourcedir)
 
     user = Bool(
@@ -133,17 +134,17 @@ class InstallKernelSpec(JupyterApp):
         "debug": base_flags["debug"],
     }
 
-    def parse_command_line(self, argv):
+    def parse_command_line(self, argv: None | list[str]) -> None:  # type:ignore[override]
         """Parse the command line args."""
         super().parse_command_line(argv)
         # accept positional arg as profile name
         if self.extra_args:
             self.sourcedir = self.extra_args[0]
         else:
-            self.log.info("No source directory specified.")
+            print("No source directory specified.", file=sys.stderr)
             self.exit(1)
 
-    def start(self):
+    def start(self) -> None:
         """Start the application."""
         if self.user and self.prefix:
             self.exit("Can't specify both user and prefix. Please choose one or the other.")
@@ -157,14 +158,12 @@ class InstallKernelSpec(JupyterApp):
             )
         except OSError as e:
             if e.errno == errno.EACCES:
-                self.log.exception(e)
+                print(e, file=sys.stderr)
                 if not self.user:
-                    self.log.warn(
-                        "Perhaps you want to install with `sudo` or `--user`?",
-                    )
+                    print("Perhaps you want to install with `sudo` or `--user`?", file=sys.stderr)
                 self.exit(1)
             elif e.errno == errno.EEXIST:
-                self.log.warn("A kernel spec is already present at %s", e.filename)
+                print(f"A kernel spec is already present at {e.filename}", file=sys.stderr)
                 self.exit(1)
             raise
 
@@ -181,7 +180,7 @@ class RemoveKernelSpec(JupyterApp):
 
     kernel_spec_manager = Instance(KernelSpecManager)
 
-    def _kernel_spec_manager_default(self):
+    def _kernel_spec_manager_default(self) -> KernelSpecManager:
         return KernelSpecManager(data_dir=self.data_dir, parent=self)
 
     flags = {
@@ -189,7 +188,7 @@ class RemoveKernelSpec(JupyterApp):
     }
     flags.update(JupyterApp.flags)
 
-    def parse_command_line(self, argv):
+    def parse_command_line(self, argv: list[str] | None) -> None:  # type:ignore[override]
         """Parse the command line args."""
         super().parse_command_line(argv)
         # accept positional arg as profile name
@@ -198,7 +197,7 @@ class RemoveKernelSpec(JupyterApp):
         else:
             self.exit("No kernelspec specified.")
 
-    def start(self):
+    def start(self) -> None:
         """Start the application."""
         self.kernel_spec_manager.ensure_native_kernel = False
         spec_paths = self.kernel_spec_manager.find_kernel_specs()
@@ -207,9 +206,10 @@ class RemoveKernelSpec(JupyterApp):
             self.exit("Couldn't find kernel spec(s): %s" % ", ".join(missing))
 
         if not (self.force or self.answer_yes):
-            self.log.info("Kernel specs to remove:")
+            print("Kernel specs to remove:")
             for name in self.spec_names:
-                self.log.info("  %s\t%s", name.ljust(20), name.ljust(20))
+                path = spec_paths.get(name, name)
+                print(f"  {name.ljust(20)}\t{path.ljust(20)}")
             answer = input("Remove %i kernel specs [y/N]: " % len(self.spec_names))
             if not answer.lower().startswith("y"):
                 return
@@ -219,12 +219,12 @@ class RemoveKernelSpec(JupyterApp):
                 path = self.kernel_spec_manager.remove_kernel_spec(kernel_name)
             except OSError as e:
                 if e.errno == errno.EACCES:
-                    self.log.info(e, file=sys.stderr)
-                    self.log.info("Perhaps you want sudo?", file=sys.stderr)
+                    print(e, file=sys.stderr)
+                    print("Perhaps you want sudo?", file=sys.stderr)
                     self.exit(1)
                 else:
                     raise
-            self.log.info("Removed %s", path)
+            print(f"Removed {path}")
 
 
 class InstallNativeKernelSpec(JupyterApp):
@@ -234,7 +234,7 @@ class InstallNativeKernelSpec(JupyterApp):
     description = """[DEPRECATED] Install the IPython kernel spec directory for this Python."""
     kernel_spec_manager = Instance(KernelSpecManager)
 
-    def _kernel_spec_manager_default(self):  # pragma: no cover
+    def _kernel_spec_manager_default(self) -> KernelSpecManager:  # pragma: no cover
         return KernelSpecManager(data_dir=self.data_dir)
 
     user = Bool(
@@ -254,7 +254,7 @@ class InstallNativeKernelSpec(JupyterApp):
         "debug": base_flags["debug"],
     }
 
-    def start(self):  # pragma: no cover
+    def start(self) -> None:  # pragma: no cover
         """Start the application."""
         self.log.warning(
             "`jupyter kernelspec install-self` is DEPRECATED as of 4.0."
@@ -263,20 +263,22 @@ class InstallNativeKernelSpec(JupyterApp):
         try:
             from ipykernel import kernelspec
         except ModuleNotFoundError:
-            self.log.info("ipykernel not available, can't install its spec.", file=sys.stderr)
+            print("ipykernel not available, can't install its spec.", file=sys.stderr)
             self.exit(1)
         try:
-            kernelspec.install(self.kernel_spec_manager, user=self.user)
+            kernelspec.install(
+                self.kernel_spec_manager, user=self.user
+            )  # type:ignore[no-untyped-call]
         except OSError as e:
             if e.errno == errno.EACCES:
-                self.log.info(e, file=sys.stderr)
+                print(e, file=sys.stderr)
                 if not self.user:
-                    self.log.info(
+                    print(
                         "Perhaps you want to install with `sudo` or `--user`?",
                         file=sys.stderr,
                     )
                 self.exit(1)
-            self.exit(e)
+            self.exit(e)  # type:ignore[arg-type]
 
 
 class ListProvisioners(JupyterApp):
@@ -285,17 +287,17 @@ class ListProvisioners(JupyterApp):
     version = __version__
     description = """List available provisioners for use in kernel specifications."""
 
-    def start(self):
+    def start(self) -> None:
         """Start the application."""
         kfp = KernelProvisionerFactory.instance(parent=self)
-        self.log.info("Available kernel provisioners:")
+        print("Available kernel provisioners:")
         provisioners = kfp.get_provisioner_entries()
 
         # pad to width of longest kernel name
         name_len = len(sorted(provisioners, key=lambda name: len(name))[-1])
 
         for name in sorted(provisioners):
-            self.log.info("  %s    %s", name.ljust(name_len), provisioners[name])
+            print(f"  {name.ljust(name_len)}    {provisioners[name]}")
 
 
 class KernelSpecApp(Application):
@@ -322,18 +324,14 @@ class KernelSpecApp(Application):
         }
     )
 
-    aliases: t.Dict[t.Union[str, t.Tuple[str, ...]], t.Union[str, t.Tuple[str, str]]] = {}
-    flags: t.Dict[
-        t.Union[str, t.Tuple[str, ...]], t.Tuple[t.Union[t.Dict[str, t.Any], Config], str]
-    ] = {}
+    aliases = {}
+    flags = {}
 
-    def start(self):
+    def start(self) -> None:
         """Start the application."""
         if self.subapp is None:
-            self.log.info(
-                "No subcommand specified. Must specify one of: %s" % list(self.subcommands)
-            )
-            self.log.info()
+            print("No subcommand specified. Must specify one of: %s" % list(self.subcommands))
+            print()
             self.print_description()
             self.print_subcommands()
             self.exit(1)
