@@ -11,7 +11,7 @@ from jupyter_client import localinterfaces
 
 def test_load_ips():
     # Override the machinery that skips it if it was called before
-    localinterfaces._load_ips.called = False
+    localinterfaces._load_ips.called = False  # type:ignore[attr-defined]
 
     # Just check this doesn't error
     localinterfaces._load_ips(suppress_exceptions=False)
